<?php

namespace App\Http\Controllers;

use App\Models\Alerta;
use App\Models\Punto;
use Illuminate\Http\Request;

/**
 * Class AlertaController
 * @package App\Http\Controllers
 */
class AlertaController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $alertas = Alerta::paginate();

        return view('alerta.index', compact('alertas'))
            ->with('i', (request()->input('page', 1) - 1) * $alertas->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $alerta = new Alerta();
        $puntos = Punto::pluck('nombre', 'id');
        return view('alerta.create', compact('alerta', 'puntos'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Alerta::$rules);

        $alerta = Alerta::create($request->all());

        return redirect()->route('alertas.index')
            ->with('success', 'Alerta created successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $alerta = Alerta::find($id);

        return view('alerta.show', compact('alerta'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $alerta = Alerta::find($id);
        $puntos = Punto::pluck('nombre', 'id');
        return view('alerta.edit', compact('alerta', 'puntos'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Alerta $alerta
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Alerta $alerta)
    {
        request()->validate(Alerta::$rules);

        $alerta->update($request->all());

        return redirect()->route('alertas.index')
            ->with('success', 'Alerta updated successfully');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $alerta = Alerta::find($id)->delete();

        return redirect()->route('alertas.index')
            ->with('success', 'Alerta deleted successfully');
    }
}
